package com.ruoyi.szxc.mapper;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcLdInfo;

/**
 * 楼栋信息Mapper接口
 * 
 * @author hs
 * @date 2024-03-16
 */
public interface SzxcLdInfoMapper 
{
    /**
     * 查询楼栋信息
     * 
     * @param id 楼栋信息主键
     * @return 楼栋信息
     */
    public SzxcLdInfo selectSzxcLdInfoById(Long id);

    /**
     * 查询楼栋信息列表
     * 
     * @param szxcLdInfo 楼栋信息
     * @return 楼栋信息集合
     */
    public List<SzxcLdInfo> selectSzxcLdInfoList(SzxcLdInfo szxcLdInfo);

    /**
     * 新增楼栋信息
     * 
     * @param szxcLdInfo 楼栋信息
     * @return 结果
     */
    public int insertSzxcLdInfo(SzxcLdInfo szxcLdInfo);

    /**
     * 修改楼栋信息
     * 
     * @param szxcLdInfo 楼栋信息
     * @return 结果
     */
    public int updateSzxcLdInfo(SzxcLdInfo szxcLdInfo);

    /**
     * 删除楼栋信息
     * 
     * @param id 楼栋信息主键
     * @return 结果
     */
    public int deleteSzxcLdInfoById(Long id);

    /**
     * 批量删除楼栋信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcLdInfoByIds(Long[] ids);
}
