package com.ruoyi.szxc.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.szxc.domain.SzxcLdInfo;
import com.ruoyi.szxc.service.ISzxcLdInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 楼栋信息Controller
 * 
 * @author hs
 * @date 2024-03-16
 */
@RestController
@RequestMapping("/szxc/ldinfo")
public class SzxcLdInfoController extends BaseController
{
    @Autowired
    private ISzxcLdInfoService szxcLdInfoService;

    /**
     * 查询楼栋信息列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:ldinfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(SzxcLdInfo szxcLdInfo)
    {
        startPage();
        List<SzxcLdInfo> list = szxcLdInfoService.selectSzxcLdInfoList(szxcLdInfo);
        return getDataTable(list);
    }

    /**
     * 导出楼栋信息列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:ldinfo:export')")
    @Log(title = "楼栋信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SzxcLdInfo szxcLdInfo)
    {
        List<SzxcLdInfo> list = szxcLdInfoService.selectSzxcLdInfoList(szxcLdInfo);
        ExcelUtil<SzxcLdInfo> util = new ExcelUtil<SzxcLdInfo>(SzxcLdInfo.class);
        util.exportExcel(response, list, "楼栋信息数据");
    }

    /**
     * 获取楼栋信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:ldinfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(szxcLdInfoService.selectSzxcLdInfoById(id));
    }

    /**
     * 新增楼栋信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:ldinfo:add')")
    @Log(title = "楼栋信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SzxcLdInfo szxcLdInfo)
    {
        //根据前端传递过来的部门存储，如果没传则存储当前用户的部门
        if(szxcLdInfo.getDeptId()==null){
            szxcLdInfo.setDeptId(getDeptId());
        }
        szxcLdInfo.setUserId(getUserId());
        return toAjax(szxcLdInfoService.insertSzxcLdInfo(szxcLdInfo));
    }

    /**
     * 修改楼栋信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:ldinfo:edit')")
    @Log(title = "楼栋信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SzxcLdInfo szxcLdInfo)
    {
        return toAjax(szxcLdInfoService.updateSzxcLdInfo(szxcLdInfo));
    }

    /**
     * 删除楼栋信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:ldinfo:remove')")
    @Log(title = "楼栋信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(szxcLdInfoService.deleteSzxcLdInfoByIds(ids));
    }
}
